@@ -29,9 +29,9 @@ except AttributeError:
     import _utils
     collections.defaultdict = _utils.defaultdict
 
-from Bio.Seq import Seq, UnknownSeq
+from Bio.Seq import UnknownSeq
 from Bio.SeqRecord import SeqRecord
-from Bio.SeqFeature import SeqFeature, FeatureLocation
+from Bio import SeqFeature
 from Bio import SeqIO
 
 def _gff_line_map(line, params):
@@ -319,7 +319,7 @@ class _AbstractMapReduceGFF:
         limit_info = self._normalize_limit_info(limit_info)
         for results in self._gff_process(gff_files, limit_info, target_lines):
             yield results
-       
+
     def _normalize_limit_info(self, limit_info):
         """Turn all limit information into tuples for identical comparisons.
         """
@@ -333,7 +333,7 @@ class _AbstractMapReduceGFF:
                     else:
                         final_limit_info[key].append(tuple(v))
         return final_limit_info
-    
+
     def _results_to_features(self, base, results):
         """Add parsed dictionaries of results to Biopython SeqFeatures.
         """
@@ -360,6 +360,9 @@ class _AbstractMapReduceGFF:
                     val = parts[1]
                 else:
                     val = tuple(parts[1:])
+                # specific directives that need special handling
+                if key == "sequence-region": # convert to Python 0-based coordinates
+                    val = (val[0], int(val[1]) - 1, int(val[2]))
                 dir_keyvals[key].append(val)
         for key, vals in dir_keyvals.items():
             for rec in base.values():
@@ -429,8 +432,8 @@ class _AbstractMapReduceGFF:
         multi_ids = collections.defaultdict(list)
         for parent in parents:
             multi_ids[parent['id']].append(parent)
-        multi_ids = [(mid, parents) for (mid, parents) in multi_ids.items()
-                if len(parents) > 1]
+        multi_ids = [(mid, ps) for (mid, ps) in multi_ids.items()
+                     if len(parents) > 1]
         multi_remap = dict()
         for mid, parents in multi_ids:
             multi_remap[mid] = _MultiIDRemapper(mid, parents)
@@ -441,10 +444,14 @@ class _AbstractMapReduceGFF:
         """
         if children.has_key(cur_parent.id):
             cur_children = children[cur_parent.id]
-            for rec_id, cur_child in cur_children:
-                cur_child, children = self._add_children_to_parent(cur_child,
-                        children)
+            ready_children = []
+            for _, cur_child in cur_children:
+                cur_child, _ = self._add_children_to_parent(cur_child, children)
+                ready_children.append(cur_child)
+            # Support Biopython features for 1.62+ CompoundLocations and pre-1.62
+            if not hasattr(SeqFeature, "CompoundLocation"):
                 cur_parent.location_operator = "join"
+            for cur_child in ready_children:
                 cur_parent.sub_features.append(cur_child)
             del children[cur_parent.id]
         return cur_parent, children
@@ -514,8 +521,8 @@ class _AbstractMapReduceGFF:
     def _get_feature(self, feature_dict):
         """Retrieve a Biopython feature from our dictionary representation.
         """
-        location = FeatureLocation(*feature_dict['location'])
-        new_feature = SeqFeature(location, feature_dict['type'],
+        location = SeqFeature.FeatureLocation(*feature_dict['location'])
+        new_feature = SeqFeature.SeqFeature(location, feature_dict['type'],
                 id=feature_dict['id'], strand=feature_dict['strand'])
         new_feature.qualifiers = feature_dict['quals']
         return new_feature
@@ -613,7 +620,6 @@ class GFFParser(_AbstractMapReduceGFF):
             else:
                 need_close = True
                 in_handle = open(gff_file)
-            found_seqs = False
             while 1:
                 line = in_handle.readline()
                 if not line:
